==> shakenfist-client-0.4.15.0rc4.tar.gz: shakenfist-client-0.4.15.0rc4/ansible/sf_snapshot.py <==
#!/usr/bin/python

# A simple Shaken Fist ansible module, with thanks to
# https://blog.toast38coza.me/custom-ansible-module-hello-world/

import json

from ansible.module_utils.basic import AnsibleModule


DOCUMENTATION = """
---
module: sf_snapshot
short_description: Create and delete Shaken Fist instance snapshots.
"""

EXAMPLES = """
- name: Snapshot a Shaken Fist instance
  sf_snapshot:
    instance_uuid: '9cd9ca86-0dd4-4ddd-aa28-822855ea4318'
    all: true
    state: present
  register: result
"""


def error(message):
    return True, False, {'error': message}


def present(module):
    if not module.params.get('instance_uuid'):
        return error('You must specify an instance_uuid when creating an instance')

    params = {
        'instance_uuid': module.params.get('instance_uuid')
    }

    extra = ''
    if module.params.get('all') and module.params['all']:
        extra += ' --all'
    params['extra'] = extra

    cmd = ('sf-client --json --async=block instance snapshot %(instance_uuid)s '
           '%(extra)s' % params)
    rc, stdout, stderr = module.run_command(
        cmd, check_rc=False, use_unsafe_shell=True)
    if rc != 0:
        return True, False, 'Command failed: %s' % stderr

    j = json.loads(stdout)
    if rc != 0:
        return True, False, j
    return False, True, j


def main():

    fields = {
        'uuid': {'required': False, 'type': 'str'},
        'instance_uuid': {'required': False, 'type': 'str'},
        'all': {'required': False, 'type': 'bool'},
        'state': {
            'default': 'present',
            'choices': ['present', 'absent'],
            'type': 'str'
        },
    }

    choice_map = {
        'present': present,
    }

    module = AnsibleModule(argument_spec=fields)
    is_error, has_changed, result = choice_map.get(
        module.params['state'])(module)

    if not is_error:
        module.exit_json(changed=has_changed, meta=result)
    else:
        module.fail_json(msg='Error manipulating instance',
                         params=module.params,
                         meta=result)


if __name__ == '__main__':
    main()

==> shakenfist-client-0.4.19.tar.gz: shakenfist-client-0.4.19/ansible/sf_snapshot.py <==
#!/usr/bin/python

# A simple Shaken Fist ansible module, with thanks to
# https://blog.toast38coza.me/custom-ansible-module-hello-world/

import json

from ansible.module_utils.basic import AnsibleModule


DOCUMENTATION = """
---
module: sf_snapshot
short_description: Create and delete Shaken Fist instance snapshots.
"""

EXAMPLES = """
- name: Snapshot just the primary disk a Shaken Fist instance
  sf_snapshot:
    instance_uuid: '9cd9ca86-0dd4-4ddd-aa28-822855ea4318'
    state: present
  register: result

- name: Snapshot all disks on a Shaken Fist instance, without blocking
  sf_snapshot:
    instance_uuid: '9cd9ca86-0dd4-4ddd-aa28-822855ea4318'
    all: true
    async: true
    state: present
  register: result

- name: Snapshot and update the "ciimage" label
  sf_snapshot:
    instance_uuid: '9cd9ca86-0dd4-4ddd-aa28-822855ea4318'
    label: ciimage
    state: present
  register: result
"""


def error(message):
    return True, False, {'error': message}


def present(module):
    if not module.params.get('instance_uuid'):
        return error('You must specify an instance_uuid when creating an instance')

    params = {
        'instance_uuid': module.params.get('instance_uuid')
    }

    extra = ''
    if module.params.get('all') and module.params['all']:
        extra += ' --all'
    if module.params.get('label'):
        extra += ' --label_name %s' % module.params['label']
    params['extra'] = extra

    params['async_strategy'] = 'block'
    if module.params.get('async') and module.params['async']:
        params['async_strategy'] = 'continue'

    cmd = ('sf-client --json --async=%(async_strategy)s '
           'instance snapshot %(instance_uuid)s %(extra)s' % params)
    rc, stdout, stderr = module.run_command(
        cmd, check_rc=False, use_unsafe_shell=True)
    if rc != 0:
        return True, False, 'Command failed: %s' % stderr

    j = json.loads(stdout)
    if rc != 0:
        return True, False, j
    return False, True, j


def main():

    fields = {
        'uuid': {'required': False, 'type': 'str'},
        'instance_uuid': {'required': False, 'type': 'str'},
        'all': {'required': False, 'type': 'bool'},
        'label': {'required': False, 'type': 'str'},

        'async': {'required': False, 'type': 'bool'},

        'state': {
            'default': 'present',
            'choices': ['present', 'absent'],
            'type': 'str'
        },
    }

    choice_map = {
        'present': present,
    }

    module = AnsibleModule(argument_spec=fields)
    is_error, has_changed, result = choice_map.get(
        module.params['state'])(module)

    if not is_error:
        module.exit_json(changed=has_changed, meta=result)
    else:
        module.fail_json(msg='Error manipulating instance',
                         params=module.params,
                         meta=result)


if __name__ == '__main__':
    main()
